@@ -28,36 +28,36 @@
 #include <tqsize.h>
 #include <tqstring.h>
 
-#include <kaboutdata.h>
-#include <kaccel.h>
-#include <kaction.h>
-#include <kapplication.h>
-#include <kcmdlineargs.h>
-#include <kconfig.h>
+#include <tdeaboutdata.h>
+#include <tdeaccel.h>
+#include <tdeaction.h>
+#include <tdeapplication.h>
+#include <tdecmdlineargs.h>
+#include <tdeconfig.h>
 #include <kcursor.h>
-#include <kdeversion.h>
-#include <kfiledialog.h>
-#include <kfilemetainfo.h>
-#include <kglobal.h>
+#include <tdeversion.h>
+#include <tdefiledialog.h>
+#include <tdefilemetainfo.h>
+#include <tdeglobal.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kio/netaccess.h>
-#include <klocale.h>
-#include <kmenubar.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <tdeio/netaccess.h>
+#include <tdelocale.h>
+#include <tdemenubar.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
 #include <kprotocolinfo.h>
 #include <kpropertiesdialog.h>
 #include <kprotocolinfo.h>
 #include <kstatusbar.h>
 #include <kstdaction.h>
 #include <kstandarddirs.h>
-#include <kstartupinfo.h>
-#include <ktoolbar.h>
+#include <tdestartupinfo.h>
+#include <tdetoolbar.h>
 #include <kurlcombobox.h>
 #include <kurlcompletion.h>
 #include <kurldrag.h>
-#include <kwin.h>
+#include <twin.h>
 #include <kstdguiitem.h>
 
 #include <kdebug.h>
@@ -92,7 +92,7 @@ static const int META_ITEM = 1;
 TQValueList<ImageWindow*> KuickShow::s_viewers;
 
 KuickShow::KuickShow( const char *name )
-    : KMainWindow( 0L, name ),
+    : TDEMainWindow( 0L, name ),
       m_slideshowCycle( 1 ),
       fileWidget( 0L ),
       dialog( 0L ),
@@ -114,12 +114,12 @@ KuickShow::KuickShow( const char *name )
     connect( m_slideTimer, TQT_SIGNAL( timeout() ), TQT_SLOT( nextSlide() ));
 
 
-    KConfig *kc = KGlobal::config();
+    TDEConfig *kc = TDEGlobal::config();
 
     bool isDir = false; // true if we get a directory on the commandline
 
     // parse commandline options
-    KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+    TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
 
     // files to display
     // either a directory to display, an absolute path, a relative path, or a URL
@@ -166,7 +166,7 @@ KuickShow::KuickShow( const char *name )
             KMimeType::Ptr mime = KMimeType::findByURL( url );
             TQString name = mime->name();
             if ( name == "application/octet-stream" ) // unknown -> stat()
-                name = KIO::NetAccess::mimetype( url, this );
+                name = TDEIO::NetAccess::mimetype( url, this );
 
 	    // text/* is a hack for bugs.kde.org-attached-images urls.
 	    // The real problem here is that NetAccess::mimetype does a HTTP HEAD, which doesn't
@@ -198,7 +198,7 @@ KuickShow::KuickShow( const char *name )
 
     else { // don't show browser, when image on commandline
         hide();
-        KStartupInfo::appStarted();
+        TDEStartupInfo::appStarted();
     }
 }
 
@@ -227,7 +227,7 @@ void KuickShow::initGUI( const KURL& startDir )
     fileWidget = new FileWidget( startURL, this, "MainWidget" );
     setFocusProxy( fileWidget );
 
-    KActionCollection *coll = fileWidget->actionCollection();
+    TDEActionCollection *coll = fileWidget->actionCollection();
 
     redirectDeleteAndTrashActions(coll);
 
@@ -246,47 +246,47 @@ void KuickShow::initGUI( const KURL& startDir )
              TQT_TQOBJECT(this), TQT_SLOT( slotDropped( const KFileItem *, TQDropEvent *, const KURL::List &)) );
 
     // setup actions
-    KAction *open = KStdAction::open( TQT_TQOBJECT(this), TQT_SLOT( slotOpenURL() ),
+    TDEAction *open = KStdAction::open( TQT_TQOBJECT(this), TQT_SLOT( slotOpenURL() ),
                                       coll, "openURL" );
 
-    KAction *print = KStdAction::print( TQT_TQOBJECT(this), TQT_SLOT( slotPrint() ),
+    TDEAction *print = KStdAction::print( TQT_TQOBJECT(this), TQT_SLOT( slotPrint() ),
                                         coll, "kuick_print" );
     print->setText( i18n("Print Image...") );
 
-    KAction *configure = new KAction( i18n("Configure %1...").arg( KGlobal::instance()->aboutData()->programName() ), "configure",
-                                      KShortcut(),
+    TDEAction *configure = new TDEAction( i18n("Configure %1...").arg( TDEGlobal::instance()->aboutData()->programName() ), "configure",
+                                      TDEShortcut(),
                                       TQT_TQOBJECT(this), TQT_SLOT( configuration() ),
                                       coll, "kuick_configure" );
-    KAction *slide = new KAction( i18n("Start Slideshow" ), "ksslide",
-                                  KShortcut( Key_F2 ),
+    TDEAction *slide = new TDEAction( i18n("Start Slideshow" ), "ksslide",
+                                  TDEShortcut( Key_F2 ),
                                   TQT_TQOBJECT(this), TQT_SLOT( startSlideShow() ),
                                   coll, "kuick_slideshow" );
-    KAction *about = new KAction( i18n( "About KuickShow" ), "about",
-                                  KShortcut(),
+    TDEAction *about = new TDEAction( i18n( "About KuickShow" ), "about",
+                                  TDEShortcut(),
                                   TQT_TQOBJECT(this), TQT_SLOT( about() ), coll, "about" );
 
-    oneWindowAction = new KToggleAction( i18n("Open Only One Image Window"),
-                                         "window_new",
-                                         KShortcut( CTRL+Key_N ), coll,
+    oneWindowAction = new TDEToggleAction( i18n("Open Only One Image Window"),
+                                         "window-new",
+                                         TDEShortcut( CTRL+Key_N ), coll,
                                          "kuick_one window" );
 
-    m_toggleBrowserAction = new KToggleAction( i18n("Show File Browser"), KShortcut( Key_Space ), coll, "toggleBrowser" );
+    m_toggleBrowserAction = new TDEToggleAction( i18n("Show File Browser"), TDEShortcut( Key_Space ), coll, "toggleBrowser" );
     m_toggleBrowserAction->setCheckedState(i18n("Hide File Browser"));
     connect( m_toggleBrowserAction, TQT_SIGNAL( toggled( bool ) ),
              TQT_SLOT( toggleBrowser() ));
 
-    KAction *showInOther = new KAction( i18n("Show Image"), KShortcut(),
+    TDEAction *showInOther = new TDEAction( i18n("Show Image"), TDEShortcut(),
                                         TQT_TQOBJECT(this), TQT_SLOT( slotShowInOtherWindow() ),
                                         coll, "kuick_showInOtherWindow" );
-    KAction *showInSame = new KAction( i18n("Show Image in Active Window"),
-                                       KShortcut(),
+    TDEAction *showInSame = new TDEAction( i18n("Show Image in Active Window"),
+                                       TDEShortcut(),
                                        TQT_TQOBJECT(this), TQT_SLOT( slotShowInSameWindow() ),
                                        coll, "kuick_showInSameWindow" );
-    KAction *showFullscreen = new KAction( i18n("Show Image in Fullscreen Mode"),
-					   KShortcut(), TQT_TQOBJECT(this), TQT_SLOT( slotShowFullscreen() ),
+    TDEAction *showFullscreen = new TDEAction( i18n("Show Image in Fullscreen Mode"),
+					   TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT( slotShowFullscreen() ),
 					   coll, "kuick_showFullscreen" );
 
-    KAction *quit = KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT(slotQuit()), coll, "quit");
+    TDEAction *quit = KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT(slotQuit()), coll, "quit");
 
     // remove TQString() parameter -- ellis
     coll->readShortcutSettings( TQString() );
@@ -314,8 +314,8 @@ void KuickShow::initGUI( const KURL& startDir )
 
     // remove the Sorting submenu (and the separator below)
     // from the main contextmenu
-    KActionMenu *sortingMenu = static_cast<KActionMenu*>( coll->action("sorting menu"));
-    KActionMenu *mainActionMenu = static_cast<KActionMenu*>( coll->action("popupMenu"));
+    TDEActionMenu *sortingMenu = static_cast<TDEActionMenu*>( coll->action("sorting menu"));
+    TDEActionMenu *mainActionMenu = static_cast<TDEActionMenu*>( coll->action("popupMenu"));
     TQPopupMenu *mainPopup = mainActionMenu->popupMenu();
     int sortingIndex = mainPopup->indexOf( sortingMenu->itemId( 0 ) );
     int separatorId = mainPopup->idAt( sortingIndex + 1 );
@@ -325,7 +325,7 @@ void KuickShow::initGUI( const KURL& startDir )
     mainActionMenu->remove( sortingMenu );
 
     // add the sorting menu and a separator into the View menu
-    KActionMenu *viewActionMenu = static_cast<KActionMenu*>( coll->action("view menu"));
+    TDEActionMenu *viewActionMenu = static_cast<TDEActionMenu*>( coll->action("view menu"));
     viewActionMenu->popupMenu()->insertSeparator( 0 );
     sortingMenu->plug( viewActionMenu->popupMenu(), 0 ); // on top of the menu
 
@@ -339,7 +339,7 @@ void KuickShow::initGUI( const KURL& startDir )
     mBar->insertItem( i18n("&Settings"), settingsMenu );
 
     // toolbar
-    KToolBar *tBar = toolBar();
+    TDEToolBar *tBar = toolBar();
     tBar->setText( i18n( "Main Toolbar" ) );
 
     coll->action("up")->plug( tBar );
@@ -374,7 +374,7 @@ void KuickShow::initGUI( const KURL& startDir )
 
     fileWidget->setFocus();
 
-    KConfig *kc = KGlobal::config();
+    TDEConfig *kc = TDEGlobal::config();
     kc->setGroup("SessionSettings");
     bool oneWindow = kc->readBoolEntry("OpenImagesInActiveWindow", true );
     oneWindowAction->setChecked( oneWindow );
@@ -382,7 +382,7 @@ void KuickShow::initGUI( const KURL& startDir )
     tBar->show();
 
     // Address box in address tool bar
-    KToolBar *addressToolBar = toolBar( "address_bar" );
+    TDEToolBar *addressToolBar = toolBar( "address_bar" );
     const int ID_ADDRESSBAR = 1;
 
     cmbPath = new KURLComboBox( KURLComboBox::Directories,
@@ -405,9 +405,9 @@ void KuickShow::initGUI( const KURL& startDir )
     dirSelected( fileWidget->url() );
 
     setCentralWidget( fileWidget );
-    setupGUI( KMainWindow::Save );
+    setupGUI( TDEMainWindow::Save );
 
-    coll->action( "reload" )->setShortcut( KStdAccel::reload() );
+    coll->action( "reload" )->setShortcut( TDEStdAccel::reload() );
     coll->action( "short view" )->setShortcut(Key_F6);
     coll->action( "detailed view" )->setShortcut(Key_F7);
     coll->action( "show hidden" )->setShortcut(Key_F8);
@@ -416,9 +416,9 @@ void KuickShow::initGUI( const KURL& startDir )
     coll->action( "separate dirs" )->setShortcut(Key_F12);
 }
 
-void KuickShow::redirectDeleteAndTrashActions(KActionCollection *coll)
+void KuickShow::redirectDeleteAndTrashActions(TDEActionCollection *coll)
 {
-    KAction *action = coll->action("delete");
+    TDEAction *action = coll->action("delete");
     if (action)
     {
         action->disconnect(fileWidget);
@@ -569,7 +569,7 @@ bool KuickShow::showImage( const KFileItem *fi,
 
 //        file->waitForDownload( this );
 //        TQString filename;
-//        KIO::NetAccess::download(fi->url(), filename, this);
+//        TDEIO::NetAccess::download(fi->url(), filename, this);
 
         if ( !safeViewer->showNextImage( fi->url() ) ) {
             m_viewer = safeViewer;
@@ -821,7 +821,7 @@ void KuickShow::slotDropped( const KFileItem *, TQDropEvent *, const KURL::List
 // try to init the WM border as it is 0,0 when the window is not shown yet.
 void KuickShow::show()
 {
-    KMainWindow::show();
+    TDEMainWindow::show();
     (void) Kuick::frameSize( winId() );
 }
 
@@ -856,7 +856,7 @@ void KuickShow::slotAdvanceImage( ImageWindow *view, int steps )
 
     if ( FileWidget::isImage( item ) ) {
 //        TQString filename;
-//        KIO::NetAccess::download(item->url(), filename, this);
+//        TDEIO::NetAccess::download(item->url(), filename, this);
         view->showNextImage( item->url() );
         if (m_slideTimer->isActive() && kdata->slideDelay)
             m_slideTimer->start( kdata->slideDelay );
@@ -883,13 +883,13 @@ bool KuickShow::eventFilter( TQObject *o, TQEvent *e )
         k = TQT_TQKEYEVENT( e );
 
     if ( k ) {
-        if ( KStdAccel::quit().contains( KKey( k ) ) ) {
+        if ( TDEStdAccel::quit().contains( KKey( k ) ) ) {
             saveSettings();
             deleteAllViewers();
             FileCache::shutdown();
             ::exit(0);
         }
-        else if ( KStdAccel::help().contains( KKey( k ) ) ) {
+        else if ( TDEStdAccel::help().contains( KKey( k ) ) ) {
             appHelpActivated();
             return true;
         }
@@ -969,19 +969,19 @@ bool KuickShow::eventFilter( TQObject *o, TQEvent *e )
                     return true;
                 }
 
-                return KMainWindow::eventFilter( o, e );
+                return TDEMainWindow::eventFilter( o, e );
             }
 
             // we definitely have a fileWidget here!
 
             KKey kkey( k );
-            if ( key == Key_Home || KStdAccel::home().contains( kkey ) )
+            if ( key == Key_Home || TDEStdAccel::home().contains( kkey ) )
             {
                 item = fileWidget->gotoFirstImage();
                 item_next = fileWidget->getNext( false );
             }
 
-            else if ( key == Key_End || KStdAccel::end().contains( kkey ) )
+            else if ( key == Key_End || TDEStdAccel::end().contains( kkey ) )
             {
                 item = fileWidget->gotoLastImage();
                 item_next = fileWidget->getPrevious( false );
@@ -1019,7 +1019,7 @@ bool KuickShow::eventFilter( TQObject *o, TQEvent *e )
 
             if ( FileWidget::isImage( item ) ) {
 //                TQString filename;
-//                KIO::NetAccess::download(item->url(), filename, this);
+//                TDEIO::NetAccess::download(item->url(), filename, this);
                 m_viewer->showNextImage( item->url() );
 
                 if ( kdata->preloadImage && item_next ) { // preload next image
@@ -1065,7 +1065,7 @@ bool KuickShow::eventFilter( TQObject *o, TQEvent *e )
     if ( ret )
         return true;
 
-    return KMainWindow::eventFilter( o, e );
+    return TDEMainWindow::eventFilter( o, e );
 }
 
 void KuickShow::configuration()
@@ -1125,7 +1125,7 @@ void KuickShow::about()
 
     aboutWidget->adjustSize();
 
-#if KDE_VERSION >= 310
+#if TDE_VERSION >= 310
     KDialog::centerOnScreen( aboutWidget );
 #else
 // Not fixed because it must be dead code now.
@@ -1143,7 +1143,7 @@ void KuickShow::about()
 }
 
 // ------ sessionmanagement - load / save current directory -----
-void KuickShow::readProperties( KConfig *kc )
+void KuickShow::readProperties( TDEConfig *kc )
 {
     assert( fileWidget ); // from SM, we should always have initGUI on startup
     TQString dir = kc->readPathEntry( "CurrentDirectory" );
@@ -1173,7 +1173,7 @@ void KuickShow::readProperties( KConfig *kc )
         show();
 }
 
-void KuickShow::saveProperties( KConfig *kc )
+void KuickShow::saveProperties( TDEConfig *kc )
 {
     kc->writeEntry( "Browser visible", fileWidget && fileWidget->isVisible() );
     if (fileWidget)
@@ -1197,7 +1197,7 @@ void KuickShow::saveProperties( KConfig *kc )
 
 void KuickShow::saveSettings()
 {
-    KConfig *kc = KGlobal::config();
+    TDEConfig *kc = TDEGlobal::config();
 
     kc->setGroup("SessionSettings");
     if ( oneWindowAction )
@@ -1228,14 +1228,14 @@ void KuickShow::initImlib()
     if ( !id ) {
         initImlibParams( idata, &par );
 
-        qWarning("*** KuickShow: Whoops, can't initialize imlib, trying my own palettefile now.");
+        tqWarning("*** KuickShow: Whoops, can't initialize imlib, trying my own palettefile now.");
         TQString paletteFile = locate( "data", "kuickshow/im_palette.pal" );
-        // ### - does the qstrdup() cure the segfault in imlib eventually?
-        char *file = qstrdup( paletteFile.local8Bit() );
+        // ### - does the tqstrdup() cure the segfault in imlib eventually?
+        char *file = tqstrdup( paletteFile.local8Bit() );
         par.palettefile = file;
         par.flags |= PARAMS_PALETTEFILE;
 
-        qWarning("Palettefile: %s", par.palettefile );
+        tqWarning("Palettefile: %s", par.palettefile );
 
         id = Imlib_init_with_params( x11Display(), &par );
 
@@ -1432,12 +1432,12 @@ void KuickShow::deleteAllViewers()
     m_viewer = 0L;
 }
 
-KActionCollection * KuickShow::actionCollection() const
+TDEActionCollection * KuickShow::actionCollection() const
 {
     if ( fileWidget )
         return fileWidget->actionCollection();
 
-    return KMainWindow::actionCollection();
+    return TDEMainWindow::actionCollection();
 }
 
 #include "kuickshow.moc"
